from functions import Virus

def main(time = 10):
    starter = Virus
    starter.open_website(time, time)

if __name__ == '__main__':
    main(1)
